# Models

::: audioclass.models
    options:
        members: False

## Model Types

- [Tensorflow Models][audioclass.models.tensorflow]
- [TFLite Models][audioclass.models.tflite]

## Models

- [Google Perch][audioclass.models.perch]
- [BirdNET][audioclass.models.birdnet]
